@@ -12,6 +12,7 @@
 ;;; Configration Variables:
 
 (require 'mhc-date)
+(require 'mhc-misc)
 (require 'mhc-day)
 (require 'mhc-schedule)
 (require 'mhc-vars)
@@ -635,7 +636,7 @@ The keys that are defined for mhc-calendar-mode are:
 (defun mhc-calendar (&optional date)
   "Display 3-month mini calendar."
   (interactive)
-  (setq date (or date (mhc-current-date) (mhc-calendar-get-date)))
+  (setq date (or date (mhc-summary-current-date) (mhc-calendar-get-date)))
   (when (and (get-buffer mhc-calendar/buffer) (set-buffer mhc-calendar/buffer))
     (setq date (or date mhc-calendar-view-date))
     (unless (mhc-date-yymm= date mhc-calendar-date)
@@ -1070,11 +1071,13 @@ The keys that are defined for mhc-calendar-mode are:
   (format "%4d" yy))
 
 (defun mhc-calendar/inserter-nengo ()
-  (if (> yy 1987)
-      (format "平成%2d年" (- yy 1988))
-    (if (> yy 1924)
-        (format "昭和%2d年" (- yy 1925))
-      "昔々")))
+  (if (or (> yy 2019) (and (= yy 2019) (> mm 4)))
+      (format "令和%2d年" (- yy 2018))
+    (if (> yy 1987)
+        (format "平成%2d年" (- yy 1988))
+      (if (> yy 1924)
+          (format "昭和%2d年" (- yy 1925))
+        "昔々"))))
 
 (defun mhc-calendar/inserter-mm ()
   (format "%d" mm))
@@ -1530,8 +1533,8 @@ The keys that are defined for mhc-calendar-mode are:
                           mhc-calendar/hnf-ignore-categories))
               (setq lst (cdr lst))))
           (with-temp-buffer
-            (insert-file-contents-as-coding-system
-	     mhc-default-coding-system mhcfile)
+            (mhc-insert-file-contents-as-coding-system
+             mhc-default-coding-system mhcfile)
             (mhc-header-decode-ewords)
             (mhc-header-narrowing
               (setq cats (mhc-header-get-value "x-sc-category"))
