@@ -15,12 +15,18 @@ module Mhc
         return @value.to_s
       end
 
+      def empty?
+        return true if @value.nil? || (@value.respond_to?(:empty?) && @value.empty?)
+        return false
+      end
+
       alias_method :to_s, :to_mhc_string
     end
 
     dir = File.dirname(__FILE__) + "/property_value"
 
     autoload :Date,                "#{dir}/date.rb"
+    autoload :DateTime,            "#{dir}/date_time.rb"
     autoload :Integer,             "#{dir}/integer.rb"
     autoload :List,                "#{dir}/list.rb"
     autoload :Period,              "#{dir}/period.rb"
