@@ -8,12 +8,25 @@ module Mhc
 
       DAYS_OF_MONTH = [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
 
-      def self.parse(string)
-        if /^(\d{4})(\d{2})(\d{2})$/ =~ string
-          # don't use super(string) because it's slow.
-          new($1.to_i, $2.to_i, $3.to_i)
-        else
-          return nil # raise ParseError
+      def self.parse(string, default = nil)
+        begin
+          # YYYYMMDD/HH:MM => DateTime
+          if /^(\d{4})(\d{2})(\d{2})\/(\d{2}):(\d{2})$/ =~ string
+            DateTime.new($1.to_i, $2.to_i, $3.to_i, $4.to_i, $5.to_i, 0)
+
+          # YYYYMMDD => Date
+          elsif /^(\d{4})(\d{2})(\d{2})$/ =~ string
+            Date.new($1.to_i, $2.to_i, $3.to_i)
+
+          # YYYYMMDD/hh:mm-HH:MM => DateTime taking YYYYMMDD, HH:MM
+          elsif /^(\d+):(\d+)$/ =~ string && default
+            DateTime.new(default.year, default.month, default.day, $1.to_i, $2.to_i, 0)
+
+          else
+            fail ParseError
+          end
+        rescue
+          raise ParseError, "invalid date string \"#{string}\""
         end
       end
 
@@ -38,7 +51,7 @@ module Mhc
           return self.today.first_day_of_month.next_month
 
         else
-          raise ParseError, "invalid date string '#{date_string}'"
+          raise ParseError, "invalid date string \"#{date_string}\""
         end
       end
 
@@ -65,7 +78,7 @@ module Mhc
           date = parse_relative($1)
           return date..date
         else
-          raise ParseError, "invalid date range string '#{range_string}'"
+          raise ParseError, "invalid date range string \"#{range_string}\""
         end
       end
 
@@ -80,12 +93,8 @@ module Mhc
         end
       end
 
-      def parse(string)
-        if /^\d{8}$/ =~ string
-          self.class.parse(string)
-        else
-          return nil # raise ParseError
-        end
+      def parse(string, default = nil)
+        self.class.parse(string, default)
       end
 
       def add_time(time = nil)
